@@ -441,6 +441,8 @@ class SelfManagedKafkaEventProperties(BaseModel):
         "KafkaBootstrapServers"
     )
     SourceAccessConfigurations: PassThroughProp = selfmanagedkafkaeventproperties("SourceAccessConfigurations")
+    StartingPosition: Optional[PassThroughProp]  # TODO: add documentation
+    StartingPositionTimestamp: Optional[PassThroughProp]  # TODO: add documentation
     Topics: PassThroughProp = selfmanagedkafkaeventproperties("Topics")
 
 
@@ -466,6 +468,7 @@ class ScheduleV2EventProperties(BaseModel):
     ScheduleExpressionTimezone: Optional[PassThroughProp] = schedulev2eventproperties("ScheduleExpressionTimezone")
     StartDate: Optional[PassThroughProp] = schedulev2eventproperties("StartDate")
     State: Optional[PassThroughProp] = schedulev2eventproperties("State")
+    OmitName: Optional[bool]  # TODO: add doc
 
 
 class ScheduleV2Event(BaseModel):
